# application\_just\_ruby

A simpler version of: <https://github.com/poise/application_ruby>

## Description

This cookbook is designed to be able to describe and deploy Ruby applications.

Note that this cookbook provides the Ruby-specific bindings for the `application` cookbook; you will find general documentation in that cookbook.

## Requirements

Chef 11.0.0 or higher required (for Chef environment use).

The following Opscode cookbooks are dependencies:

* application

## Resources/Providers

The LWRP provided by this cookbook is not meant to be used by itself; make sure you are familiar with the `application` cookbook before proceeding.

### `just_ruby`

The `just_ruby` sub-resource LWRP deals with deploying Ruby apps from an SCM repository. It uses the `deploy_revision` LWRP to perform the bulk of its tasks, and many concepts and parameters map directly to it. Check the documentation for `deploy_revision` for more information.

Gems will be installed with `bundle install --deployment`, which results in gems being installed inside the application directory.

When running Bundler, unnecessary groups will be skipped. The list of groups to skip is determined with this algorithm:

* start with this Array: `development test cucumber staging production`;
* the group corresponding to the current environment will be removed from the Array;
* if the `bundler_without_groups` attribute is set, those groups will be added to the Array.

For example, for a node running in the `production` Chef environment, and given:

    bundler_without_groups ["mysql"]

Bundler will be run with:

    bundle install --without development test cucumber staging mysql

#### Attribute Parameters

- bundle\_command: The command to execute when calling bundler commands. Useful for specifing alternate commands such as RVM wrappers. Defaults to `bundle`.
- bundle\_options: additional options which will be appended to the end of the `bundle` command string. Useful for capturing the output to a file using the tee command
e.g. `bundle_options "2>&1 | tee -a \some\log\file.log"` 
- bundler\_deployment: if true, Bundler will be run with the `--deployment` options.
- bundler\_without\_groups: an Array of additional Bundler groups to skip

## Usage

A sample recipe that uses the `rbenv` cookbook to provide ruby and `application_procfile` to start the app:

```ruby
include_recipe 'rbenv::default'
include_recipe 'rbenv::ruby_build'
include_recipe 'application_procfile'

rbenv_ruby '2.1.2' do
  global true
end

rbenv_gem 'bundler' do
  ruby_version '2.1.2'
end

application 'example' do
  path '/srv/example'

  owner 'ubuntu'
  group 'ubuntu'

  packages ['git']
  repository 'git@github.com:user/example.git'

  deploy_key File.read(File.expand_path('../../deploy_key', __FILE__))

  environment 'PATH_PREFIX' => '/opt/rbenv/shims/'

  just_ruby do
    bundle_command '/opt/rbenv/shims/bundle'
  end
  
  procfile do
    app 1
  end
end
```
